/*
 * MMap+ - 3d image viewer
 * Copyright 2005, 2006 Masahide Miyake
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef __WINDOW_H__
#define __WINDOW_H__

void window_create (void);
void window_menu_mark_sensitive (gboolean bool);
void window_menu_saveimage_sensitive (gboolean bool);
void window_menu_selector_sensitive (gboolean bool);
void window_menu_route_sensitive (gboolean bool);
void window_set_mark_submenu (void);

#endif /* __WINDOW_H__ */
